/** ###################################################################
**     Filename  : Display.C
**     Project   : pehod
**     Processor : MC9S08AW16CFG
**     Compiler  : CodeWarrior HCS08 C Compiler
**     Date/Time : 26.5.2008, 22:57
**     Contents  :
**         User source code
**
**     (c) Copyright UNIS, spol. s r.o. 1997-2006
**     UNIS, spol. s r.o.
**     Jundrovska 33
**     624 00 Brno
**     Czech Republic
**     http      : www.processorexpert.com
**     mail      : info@processorexpert.com
** ###################################################################*/

/* MODULE Display */

/*************************************************************************
 *
 * Projekt:     GPS hodiny
 * Autor:       Ales Povalac, <alpov@alpov.net>
 *
 *************************************************************************/         

#include "DisplayTimer.h"
#include "CharDrive.h"
#include "ShDI.h"
#include "ShSCK.h"
#include "ShRCK.h"
#include "Display.h"

unsigned char digit_segs[10] = {
  0b00111111,
  0b00000110,
  0b01011011,
  0b01001111,
  0b01100110,
  0b01101101,
  0b01111101,
  0b00000111,
  0b01111111,
  0b01100111,
};


static unsigned char diplay_data[10];


void send_tpic(unsigned int value)
{
  unsigned int i;
  
  for (i = 0; i < 16; i++) {
    ShDI_PutVal((value & 0x8000) ? 1 : 0);
    value <<= 1;
    nop();
    ShSCK_SetVal();
    nop();
    ShSCK_ClrVal();
  }
  nop();
  ShDI_ClrVal();
  ShRCK_SetVal();
  nop();
  ShRCK_ClrVal();
}


void display_timer(void)
{
  static unsigned char seg = 0;
  unsigned int data;
  unsigned char drive;
  
  switch (seg) {
    case 0:
      data = (diplay_data[0] << 8) + diplay_data[6];
      drive = 0x01;
      seg = 1;
      break;
    
    case 1:
      data = (diplay_data[1] << 8) + diplay_data[7];
      drive = 0x02;
      seg = 2;
      break;
    
    case 2:
      data = (diplay_data[2] << 8) + diplay_data[8];
      drive = 0x04;
      seg = 3;
      break;
    
    case 3:
      data = (diplay_data[3] << 8) + diplay_data[9];
      drive = 0x08;
      seg = 4;
      break;
    
    case 4:
      data = (diplay_data[4] << 8);
      drive = 0x10;
      seg = 5;
      break;
    
    case 5:
      data = (diplay_data[5] << 8);
      drive = 0x20;
      seg = 0;
      break;
    
    default:
      seg = 0;
  }
  
  send_tpic(data);
  CharDrive_PutVal(drive);
}


void show_time(unsigned char hour, unsigned char min, unsigned char sec)
{
  static unsigned int ch;
  
  ch = hour / 10;
  diplay_data[0] = digit_segs[ch];
  ch = hour % 10;
  diplay_data[1] = digit_segs[ch] | 0x80; // dvojtecka
  
  ch = min / 10;
  diplay_data[2] = digit_segs[ch];
  ch = min % 10;
  diplay_data[3] = digit_segs[ch];
  
  ch = sec / 10;
  diplay_data[4] = digit_segs[ch];
  ch = sec % 10;
  diplay_data[5] = digit_segs[ch];
}


void show_date(unsigned char day, unsigned char month)
{
  unsigned char ch;
  
  ch = day / 10;
  if (ch > 0)
    diplay_data[6] = digit_segs[ch];
  else
    diplay_data[6] = 0;
  
  ch = day % 10;
  diplay_data[7] = digit_segs[ch] | 0x80; // tecka
  
  ch = month / 10;
  if (ch > 0)
    diplay_data[8] = digit_segs[ch];
  else
    diplay_data[8] = 0;
  
  ch = month % 10;
  diplay_data[9] = digit_segs[ch] | 0x80; // tecka
}


/* END Display */
