/** ###################################################################
**     Filename  : Events.H
**     Project   : pehod
**     Processor : MC9S08AW16CFG
**     Beantype  : Events
**     Version   : Driver 01.02
**     Compiler  : CodeWarrior HCS08 C Compiler
**     Date/Time : 26.5.2008, 22:45
**     Abstract  :
**         This is user's event module.
**         Put your event handler code here.
**     Settings  :
**     Contents  :
**         DisplayTimer_OnInterrupt - void DisplayTimer_OnInterrupt(void);
**         UART_OnRxChar            - void UART_OnRxChar(void);
**         UART_OnFullRxBuf         - void UART_OnFullRxBuf(void);
**
**     (c) Copyright UNIS, spol. s r.o. 1997-2006
**     UNIS, spol. s r.o.
**     Jundrovska 33
**     624 00 Brno
**     Czech Republic
**     http      : www.processorexpert.com
**     mail      : info@processorexpert.com
** ###################################################################*/

#ifndef __Events_H
#define __Events_H
/* MODULE Events */

#include "PE_Types.h"
#include "PE_Error.h"
#include "PE_Const.h"
#include "IO_Map.h"
#include "UART.h"
#include "DisplayTimer.h"
#include "CharDrive.h"
#include "ShDI.h"
#include "ShSCK.h"
#include "ShRCK.h"
#include "LED.h"

void DisplayTimer_OnInterrupt(void);
/*
** ===================================================================
**     Event       :  DisplayTimer_OnInterrupt (module Events)
**
**     From bean   :  DisplayTimer [TimerInt]
**     Description :
**         When a timer interrupt occurs this event is called (only
**         when the bean is enabled - <Enable> and the events are
**         enabled - <EnableEvent>). This event is enabled only if a
**         <interrupt service/event> is enabled.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

void UART_OnRxChar(void);
/*
** ===================================================================
**     Event       :  UART_OnRxChar (module Events)
**
**     From bean   :  UART [AsynchroSerial]
**     Description :
**         This event is called after a correct character is
**         received.
**         The event is available only when the <Interrupt
**         service/event> property is enabled and either the
**         <Receiver> property is enabled or the <SCI output mode>
**         property (if supported) is set to Single-wire mode.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/

/* END Events */
#endif /* __Events_H*/

/*
** ###################################################################
**
**     This file was created by UNIS Processor Expert 3.01 [03.92]
**     for the Freescale HCS08 series of microcontrollers.
**
** ###################################################################
*/
